local contributionEtaData = {
	[1] = {}, -- Mage Tower
	[3] = {}, -- Command Center
	[4] = {} -- Nether Disruptor
};

local contribTicker = C_Timer.NewTicker(5, function()
	for k, v in pairs(contributionEtaData) do
		local state, pct = C_ContributionCollector.GetState(k);
		if state == 1 then
			if not v.hasData then
				v.hasData = true;
				v.startTime = time();
				v.startPct = pct;
				v.eta = 0;
			end
			local pctDiff = pct - v.startPct;
			local timeDiff = time() - v.startTime;
			if timeDiff < 1 or pctDiff < 0.01 then return end
			local buildSpeed = pctDiff * 100 / timeDiff; -- pct/sec
			local pctLeft = 100 - pct * 100; -- pct
			v.eta = pctLeft / buildSpeed; -- pct / pct/sec
			--print("Mage tower: ", pctDiff, timeDiff, buildSpeed, v.eta, SecondsToTime(v.eta));
		else
			v.hasData = false;
			v.startTime = 0;
			v.startPct = 0;
			v.eta = 0;
		end
	end
end)

local function MyWorldMapPOI_AddContributionsToTooltip(tooltip, ...)
	for i = 1, select("#", ...) do
		local contributionID = select(i, ...);
		local contributionName = C_ContributionCollector.GetName(contributionID);
		local state, stateAmount, timeOfNextStateChange = C_ContributionCollector.GetState(contributionID);
		local appearanceData = CONTRIBUTION_APPEARANCE_DATA[state];

		if i ~= 1 then
			tooltip:AddLine(" ");
		end

		tooltip:AddLine(contributionName, HIGHLIGHT_FONT_COLOR:GetRGB());

		local tooltipLine = appearanceData.tooltipLine;
		if tooltipLine then
			if timeOfNextStateChange and appearanceData.tooltipUseTimeRemaining then
				local time = math.max(timeOfNextStateChange - GetServerTime(), 60); -- Never display times below one minute
				tooltipLine = tooltipLine:format(SecondsToTime(time, true, true, 1));
			elseif contributionEtaData[contributionID] and contributionEtaData[contributionID].hasData and contributionEtaData[contributionID].eta > 0 then
				local etaData = contributionEtaData[contributionID];
				tooltipLine = tooltipLine:format(FormatPercentage(stateAmount)) .. " (ETA " .. SecondsToTime(etaData.eta) .. ")";
			else
				tooltipLine = tooltipLine:format(FormatPercentage(stateAmount));
			end

			tooltip:AddLine(tooltipLine, appearanceData.stateColor:GetRGB());
		end
	end
end

local function MyWorldMapPOI_OnEnter(self)
	if ( self.specialPOIInfo and self.specialPOIInfo.onEnter ) then
		return
	else
		if self.landmarkType == LE_MAP_LANDMARK_TYPE_CONTRIBUTION then
			WorldMapTooltip:SetOwner(self, "ANCHOR_RIGHT");
			WorldMapTooltip:SetText(self.name, HIGHLIGHT_FONT_COLOR:GetRGB());
			WorldMapTooltip:AddLine(" ");

			MyWorldMapPOI_AddContributionsToTooltip(WorldMapTooltip, C_ContributionCollector.GetManagedContributionsForCreatureID(self.mapLinkID));

			WorldMapTooltip:Show();
		end
	end
end

hooksecurefunc("WorldMapPOI_OnEnter", MyWorldMapPOI_OnEnter);
